Introduction
============

`stunnel`_ can be used to create encrypted TCP tunnels between two service
ports, either on the same host or on separate hosts.

Encryption is done using SSL certificates. This Ansible role can be used to
create tunnels between two or more hosts, using Ansible inventory groups.

.. _stunnel: http://stunnel.org/

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
